@@ -6,7 +6,7 @@ from pdf2image import convert_from_bytes
 import signer_pdf.sign_generator as sign_generator
 
 
-def sign(name, date, a_hash, position, in_file):
+def sign(name, date, a_hash, position, in_file, right_top=False):
     original = PyPDF2.PdfFileReader(in_file, strict=False)
     first_page = original.getPage(0)
 
@@ -18,7 +18,7 @@ def sign(name, date, a_hash, position, in_file):
 
     images = convert_from_bytes(pdf_with_signed_page_bytes.read())
 
-    signed_page_bytes = sign_generator.convert(name, date, a_hash, position, images[0])
+    signed_page_bytes = sign_generator.convert(name, date, a_hash, position, images[0], right_top)
     signed_page = PyPDF2.PdfFileReader(signed_page_bytes).getPage(0)
 
     media_3 = float(first_page['/MediaBox'][3])
